export default {
    // common
    Publié: {
        en: "Published",
        fr: "Publié",
        de: "Veröffentlicht",
        nl: "Gepubliceerd",
    },
    Actualisé: {
        en: "Updated",
        fr: "Actualisé",
        de: "Aktualisiert",
        nl: "Bijgewerkt",
    },
    Événements: {
        en: "Events",
        fr: "Événements",
        de: "Veranstaltungen",
        nl: "Evenementen",
    },
    Actualités: {
        en: "News",
        fr: "Actualités",
        de: "Nachrichten",
        nl: "Nieuws",
    },
    Contacts: {
        en: "Contacts",
        fr: "Contacts",
        de: "Kontakte",
        nl: "Contacten",
    },
    "Infos pratiques": {
        en: "Practical information",
        fr: "Infos pratiques",
        de: "Praktische Informationen",
        nl: "Praktische informatie",
    },
    "Chargement...": {
        en: "Loading",
        fr: "Chargement...",
        de: "Laden",
        nl: "Laden...",
    },
    Recherche: {
        en: "Search",
        fr: "Recherche",
        de: "Suche",
        nl: "Zoeken",
    },
    Thématiques: {
        en: "Themes",
        fr: "Thématiques",
        de: "Themen",
        nl: "Thema's",
    },
    "Je suis": {
        en: "I am",
        fr: "Je suis",
        de: "Ich bin",
        nl: "Ik ben",
    },
    Catégories: {
        en: "Categories",
        fr: "Catégories",
        de: "Kategorien",
        nl: "Categorieën",
    },
    "Catégories locale": {
        en: "Local categories",
        fr: "Catégories locale",
        de: "Lokale Kategorien",
        nl: "Lokale categorieën",
    },
    "Catégories spécifiques": {
        en: "Specific categories",
        fr: "Catégories spécifiques",
        de: "Spezifische Kategorien",
        nl: "Specifieke categorieën",
    },
    Quoi: {
        en: "What",
        fr: "Quoi",
        de: "Was",
        nl: "Wat",
    },
    Facilités: {
        en: "Facilities",
        fr: "Facilités",
        de: "Einrichtungen",
        nl: "Faciliteiten",
    },
    "Plus de résultats": {
        en: "More results",
        fr: "Plus de résultats",
        de: "Mehr Ergebnisse",
        nl: "Meer resultaten",
    },
    "Aucun résultat": {
        en: "No result",
        fr: "Aucun résultat",
        de: "Kein Ergebnis",
        nl: "Geen resultaat",
    },
    Résultats: {
        en: "Results",
        fr: "Résultats",
        de: "Ergebnisse",
        nl: "Resultaten",
    },
    Retour: {
        en: "Return",
        fr: "Retour",
        de: "Zurück",
        nl: "Terug",
    },
    Téléchargements: {
        en: "Downloads",
        fr: "Téléchargements",
        de: "Downloads",
        nl: "Downloads",
    },
    Billetterie: {
        en: "Ticketing",
        fr: "Billetterie",
        de: "Tickets",
        nl: "Ticketverkoop",
    },
    "Lien vers la vidéo": {
        en: "Link to video",
        fr: "Lien vers la vidéo",
        de: "Link zum Video",
        nl: "Link naar video",
    },
    "Participation en ligne": {
        en: "Join online",
        fr: "Participation en ligne",
        de: "Online teilnehmen",
        nl: "Doe online mee",
    },
    "Actualités trouvées": {
        en: " News found",
        fr: " Actualités trouvées",
        de: " Nachrichten gefunden",
        nl: " Nieuws gevonden",
    },
    "Actualité trouvée": {
        en: " News found",
        fr: " Actualité trouvée",
        de: " Nachricht gefunden",
        nl: " Nieuws gevonden",
    },
    "Aucune actualité n'a été trouvée": {
        en: "No news was found",
        fr: "Aucune actualité n'a été trouvée",
        de: "Keine Nachrichten gefunden",
        nl: "Geen nieuws gevonden",
    },
    "Proposer une actualité": {
        en: "Suggest a news",
        fr: "Proposer une actualité",
        de: "Nachricht vorschlagen",
        nl: "Nieuws voorstellen",
    },
    "événements trouvés": {
        en: " Events found",
        fr: " Événements trouvés",
        de: " Veranstaltungen gefunden",
        nl: " Evenementen gevonden",
    },
    "projets trouvés": {
        en: " Projects found",
        fr: " Projets trouvés",
        de: " Projekte gefunden",
        nl: " Projecten gevonden",
    },
    "projet trouvé": {
        en: " Project found",
        fr: " Projet trouvé",
        de: " Projekt gefunden",
        nl: " Project gevonden",
    },
    "événement trouvé": {
        en: " Event found",
        fr: " Événement trouvé",
        de: " Veranstaltung gefunden",
        nl: " Evenement gevonden",
    },
    Gratuit: {
        en: "Free",
        fr: "Gratuit",
        de: "Kostenlos",
        nl: "Gratis",
    },
    "Aucun événement n'a été trouvé": {
        en: "No event was found",
        fr: "Aucun événement n'a été trouvé",
        de: "Keine Veranstaltungen gefunden",
        nl: "Geen evenement gevonden",
    },
    "Proposer un événement": {
        en: "Suggest a event",
        fr: "Proposer un événement",
        de: "Veranstaltung vorschlagen",
        nl: "Evenement voorstellen",
    },
    "Infos pratiques": {
        en: "Practical information",
        fr: "Infos pratiques",
        de: "Praktische Informationen",
        nl: "Praktische informatie",
    },
    "Accessible aux PMR": {
        en: "Accessibility for PRM",
        fr: "Accessible aux PMR",
        de: "Barrierefreiheit für PMR",
        nl: "Toegankelijk voor PRM",
    },
    "Lien de l'événement": {
        en: "Event link",
        fr: "Lien de l'événement",
        de: "Veranstaltungslink",
        nl: "Evenement link",
    },
    "contacts trouvés": {
        en: " Contact found",
        fr: " Contacts trouvés",
        de: " Kontakt gefunden",
        nl: " Contact gevonden",
    },
    "contact trouvé": {
        en: " Contact found",
        fr: " Contact trouvé",
        de: " Kontakt gefunden",
        nl: " Contact gevonden",
    },
    "Aucun contact n'a été trouvé": {
        en: "No contact was found",
        fr: "Aucun contact n'a été trouvé",
        de: "Kein Kontakt gefunden",
        nl: "Geen contact gevonden",
    },
    "Proposer un contact": {
        en: "Suggest a contact",
        fr: "Proposer un contact",
        de: "Kontakt vorschlagen",
        nl: "Contact voorstellen",
    },
    "projets trouvés": {
        en: " Projects found",
        fr: " Projets trouvés",
        de: " Projekte gefunden",
        nl: " Projecten gevonden",
    },
    "projet trouvé": {
        en: " Project found",
        fr: " Projet trouvé",
        de: " Projekt gefunden",
        nl: " Project gevonden",
    },
    "Aucun projet n'a été trouvé": {
        en: "No project was found",
        fr: "Aucun projet n'a été trouvé",
        de: "Kein Projekt gefunden",
        nl: "Geen project gevonden",
    },
    "Proposer un projet": {
        en: "Suggest a project",
        fr: "Proposer un projet",
        de: "Projekt vorschlagen",
        nl: "Project voorstellen",
    },
    Quand: {
        en: "When",
        fr: "Quand",
        de: "Wann",
        nl: "Wanneer",
    },
    "Toutes les dates": {
        en: "All dates",
        fr: "Toutes les dates",
        de: "Alle Daten",
        nl: "Alle data",
    },
    "Aujourd'hui": {
        en: "Today",
        fr: "Aujourd'hui",
        de: "Heute",
        nl: "Vandaag",
    },
    Demain: {
        en: "Tomorrow",
        fr: "Demain",
        de: "Morgen",
        nl: "Morgen",
    },
    "Ce week-end": {
        en: "This weekend",
        fr: "Ce week-end",
        de: "Dieses Wochenende",
        nl: "Dit weekend",
    },
    "Cette semaine": {
        en: "This week",
        fr: "Cette semaine",
        de: "Diese Woche",
        nl: "Deze week",
    },
    "Ce mois-ci": {
        en: "This month",
        fr: "Ce mois-ci",
        de: "Diesen Monat",
        nl: "Deze maand",
    },
    "Personnalisé (Du ... au ...)": {
        en: "Custom (From ... to ...)",
        fr: "Personnalisé (Du ... au ...)",
        de: "Benutzerdefiniert (Von ... bis ...)",
        nl: "Aangepast (Van ... tot ...)",
    },
    Le: {
        en: "On",
        fr: "Le",
        de: "Am",
        nl: "Op",
    },
    de: {
        en: "of",
        fr: "de",
        de: "von",
        nl: "van",
    },
    à: {
        en: "at",
        fr: "à",
        de: "um",
        nl: "om",
    },
    Du: {
        en: "From",
        fr: "Du",
        de: "Von",
        nl: "Van",
    },
    au: {
        en: "to",
        fr: "au",
        de: "bis",
        nl: "tot",
    },
    Personnalisé: {
        en: "Custom",
        fr: "Personnalisé",
        de: "Benutzerdefiniert",
        nl: "Aangepast",
    },
    Monday: {
        en: "Monday",
        fr: "Lundi",
        de: "Montag",
        nl: "Maandag",
    },
    Tuesday: {
        en: "Tuesday",
        fr: "Mardi",
        de: "Dienstag",
        nl: "Dinsdag",
    },
    Wednesday: {
        en: "Wednesday",
        fr: "Mercredi",
        de: "Mittwoch",
        nl: "Woensdag",
    },
    Thursday: {
        en: "Thursday",
        fr: "Jeudi",
        de: "Donnerstag",
        nl: "Donderdag",
    },
    Friday: {
        en: "Friday",
        fr: "Vendredi",
        de: "Freitag",
        nl: "Vrijdag",
    },
    Saturday: {
        en: "Saturday",
        fr: "Samedi",
        de: "Samstag",
        nl: "Zaterdag",
    },
    Sunday: {
        en: "Sunday",
        fr: "Dimanche",
        de: "Sonntag",
        nl: "Zondag",
    },
    Fermé: {
        en: "Closed",
        fr: "Fermé",
        de: "Geschlossen",
        nl: "Gesloten",
    },
    Ouvert: {
        en: "Open",
        fr: "Ouvert",
        de: "Geöffnet",
        nl: "Open",
    },
    Itinéraire: {
        en: "Itinerary",
        fr: "Itinéraire",
        de: "Route",
        nl: "Route",
    },
    "Filtrer par profil": {
        en: "Filter by profile",
        fr: "Filtrer par profil",
        de: "Nach Profile filtern",
        nl: "Filteren op profiel",
    },
    "Filtrer par thématique": {
        en: "Filter by theme",
        fr: "Filtrer par thématique",
        de: "Nach Thema filtern",
        nl: "Filteren op thema",
    },
    Commentaires: {
        en: "Comments",
        fr: "Commentaires",
        de: "Kommentare",
        nl: "Reacties",
    },
    "Ajouter un commentaire": {
        en: "Add a comment",
        fr: "Ajouter un commentaire",
        de: "Kommentar hinzufügen",
        nl: "Reactie toevoegen",
    },
};
